@@ -128,7 +128,7 @@ NumericVector fmeanCpp(const NumericVector& x, int ng = 0, const IntegerVector&
       if(g.size() != l) stop("length(g) must match nrow(X)");
       if(narm) {
         NumericVector sum(ng, NA_REAL); // Other way ?? -> Nope, this is as good as it gets !!
-        NumericVector sumw = no_init_vector(ng); // what if only NA ?? -> Works !! for some reason no problem !!, and faster !!
+        NumericVector sumw(ng); // = no_init_vector(ng); // no init works!! but gives valgrind issue !!
         for(int i = l; i--; ) {
           if(std::isnan(x[i]) || std::isnan(wg[i])) continue; // faster way to code this ??? -> Not Bad at all -> index for g[i]-1?? -> Nope, no noticeable improvement !!
           if(std::isnan(sum[g[i]-1])) {
@@ -224,7 +224,7 @@ SEXP fmeanmCpp(const NumericMatrix& x, int ng = 0, const IntegerVector& g = 0, c
         // NumericVector sumt(ng*col, NA_REAL); // A tiny speed gain, but not much !! Same memory efficiency !!
         // sumt.attr("dim") = Dimension(ng, col);
         // NumericMatrix sum = as<NumericMatrix>(sumt);
-        IntegerVector nj = no_init_vector(ng); // better ??
+        IntegerVector nj(ng); // = no_init_vector(ng); // better for valgrind !!
         for(int j = col; j--; ) {
           NumericMatrix::ConstColumn column = x( _ , j);
           NumericMatrix::Column sumj = sum( _ , j);
@@ -365,7 +365,7 @@ SEXP fmeanmCpp(const NumericMatrix& x, int ng = 0, const IntegerVector& g = 0, c
             }
           }
           for(int i = ng; i--; ) sumj[i] /= sumwj[i];
-          // sumj = sumj/sumwj;
+          // sumj = sumj/sumwj; // This gives erriir because sumj is matrix column !!
         }
         colnames(sum) = colnames(x);  // extremely efficient !!
         return sum;
@@ -393,7 +393,7 @@ SEXP fmeanmCpp(const NumericMatrix& x, int ng = 0, const IntegerVector& g = 0, c
             }
           }
           for(int i = ng; i--; ) sumj[i] /= sumwj[i];
-          // sumj = sumj/sumwj;
+          // sumj = sumj/sumwj; // This gives erriir because sumj is matrix column !!
         }
         colnames(sum) = colnames(x);  // extremely efficient !!
         return sum;
@@ -615,8 +615,8 @@ SEXP fmeanlCpp(const List& x, int ng = 0, const IntegerVector& g = 0, const SEXP
               sumwj[g[i]-1] += wg[i];
             }
           }
-          // sumj = sumj/sumwj;
-          for(int i = ng; i--; ) sumj[i] /= sumwj[i];
+          sumj = sumj/sumwj;
+          // for(int i = ng; i--; ) sumj[i] /= sumwj[i];
           SHALLOW_DUPLICATE_ATTRIB(sumj, column);
           sum[j] = sumj;
         }
@@ -642,8 +642,8 @@ SEXP fmeanlCpp(const List& x, int ng = 0, const IntegerVector& g = 0, const SEXP
               sumwj[g[i]-1] += wg[i];
             }
           }
-          // sumj = sumj/sumwj;
-          for(int i = ng; i--; ) sumj[i] /= sumwj[i];
+          sumj = sumj/sumwj;
+          // for(int i = ng; i--; ) sumj[i] /= sumwj[i];
           SHALLOW_DUPLICATE_ATTRIB(sumj, column);
           sum[j] = sumj;
         }
