@@ -32,15 +32,15 @@ test_that("TRA performs like fbetween and fwithin", {
     expect_equal(TRA(v, fmean(v, f), 1L, f), fbetween(v, f, fill = TRUE))
     expect_equal(TRA(v, fmean(v, f), 2L, f), fbetween(v, f))
     expect_equal(TRA(v, fmean(v, f), 3L, f), fwithin(v, f))
-    expect_equal(TRA(v, fmean(v, f), 4L, f), fwithin(v, f, add.global.mean = TRUE))
+    expect_equal(TRA(v, fmean(v, f), 4L, f), fwithin(v, f, mean = "overall.mean"))
     expect_equal(TRA(m, fmean(m, f), 1L, f), fbetween(m, f, fill = TRUE))
     expect_equal(TRA(m, fmean(m, f), 2L, f), fbetween(m, f))
     expect_equal(TRA(m, fmean(m, f), 3L, f), fwithin(m, f))
-    expect_equal(TRA(m, fmean(m, f), 4L, f), fwithin(m, f, add.global.mean = TRUE))
+    expect_equal(TRA(m, fmean(m, f), 4L, f), fwithin(m, f, mean = "overall.mean"))
     expect_equal(TRA(d, fmean(d, f), 1L, f), fbetween(d, f, fill = TRUE))
     expect_equal(TRA(d, fmean(d, f), 2L, f), fbetween(d, f))
     expect_equal(TRA(d, fmean(d, f), 3L, f), fwithin(d, f))
-    expect_equal(TRA(d, fmean(d, f), 4L, f), fwithin(d, f, add.global.mean = TRUE))
+    expect_equal(TRA(d, fmean(d, f), 4L, f), fwithin(d, f, mean = "overall.mean"))
 })
 
 test_that("TRA gives errors for wrong input", {
@@ -56,9 +56,9 @@ test_that("TRA gives errors for wrong input", {
   expect_error(TRA(v, fmean(v, f), "-", f[-1]))
   expect_error(TRA(m, fmean(m, f), "-", f[-1]))
   expect_error(TRA(d, fmean(d, f), "-", f[-1]))
-  expect_error(TRA(v, fmean(v), 9L))
-  expect_error(TRA(m, fmean(m), 9L))
-  expect_error(TRA(d, fmean(d), 9L))
+  expect_error(TRA(v, fmean(v), 19L))
+  expect_error(TRA(m, fmean(m), 19L))
+  expect_error(TRA(d, fmean(d), 19L))
   expect_error(TRA(v, fmean(v), "bla"))
   expect_error(TRA(m, fmean(m), "bla"))
   expect_error(TRA(d, fmean(d), "bla"))
